# -*- Perl -*-
#
#***********************************************************************
#
# package MailFilter::Settings
#
# Suggested minimum-protection filter for Microsoft Windows clients, plus
# SpamAssassin checks if SpamAssassin is installed.
#
# Copyright (C) 2002 Roaring Penguin Software Inc.
#
# This program may be distributed under the terms of the GNU General
# Public License, Version 2, or (at your option) any later version.
#
# Based on:
# $Id: suggested-minimum-filter-for-windows-clients,v 1.81 2004/10/26 18:34:33 dfs Exp $
#***********************************************************************

package MailFilter::Settings;

use strict;
use warnings;
use Mimedefang qw(:config :logging :global :spamassassin);
require Exporter;

use vars qw(
    @FilterModules
    $modules_debug
);

# export variables used to control mimedefang-filter-select
our @ISA = qw(Exporter);
our %EXPORT_TAGS = (
    config => [qw{
        @FilterModules
        $modules_debug
    }],
);
# put all exported items also in @EXPORT_OK using the Exporter
Exporter::export_ok_tags('config');

#***********************************************************************
# Set administrator's e-mail address here.  The administrator receives
# quarantine messages and is listed as the contact for site-wide
# MIMEDefang policy.  A good example would be 'defang-admin@mydomain.com'
#***********************************************************************
$AdminAddress = 'postmaster@localhost';
$AdminName = "MIMEDefang Administrator's Full Name";

#***********************************************************************
# Set the e-mail address from which MIMEDefang quarantine warnings and
# user notifications appear to come.  A good example would be
# 'mimedefang@mydomain.com'.  Make sure to have an alias for this
# address if you want replies to it to work.
#***********************************************************************
$DaemonAddress = 'mimedefang@localhost';

#***********************************************************************
# If you set $AddWarningsInline to 1, then MIMEDefang tries *very* hard
# to add warnings directly in the message body (text or html) rather
# than adding a separate "WARNING.TXT" MIME part.  If the message
# has no text or html part, then a separate MIME part is still used.
#***********************************************************************
$AddWarningsInline = 0;

#***********************************************************************
# To enable syslogging of virus and spam activity, add the following
# to the filter:
# md_graphdefang_log_enable();
# You may optionally provide a syslogging facility by passing an
# argument such as:  md_graphdefang_log_enable('local4');  If you do this, be
# sure to setup the new syslog facility (probably in /etc/syslog.conf).
# An optional second argument causes a line of output to be produced
# for each recipient (if it is 1), or only a single summary line
# for all recipients (if it is 0.)  The default is 1.
# Comment this line out to disable logging.
#***********************************************************************
md_graphdefang_log_enable('mail', 1);

#***********************************************************************
# Uncomment this to block messages with more than 50 parts.  This will
# *NOT* work unless you're using Roaring Penguin's patched version
# of MIME tools, version MIME-tools-5.411a-RP-Patched-02 or later.
#
# WARNING: DO NOT SET THIS VARIABLE unless you're using at least
# MIME-tools-5.411a-RP-Patched-02; otherwise, your filter will fail.
#***********************************************************************
# $MaxMIMEParts = 50;

#***********************************************************************
# Set various stupid things your mail client does below.
#***********************************************************************

# Set the next one if your mail client cannot handle multiple "inline"
# parts.
$Stupidity{"NoMultipleInlines"} = 0;

# setting this variable to true causes each independent MailFilter module
# call to be logged.
$modules_debug = 0;

@FilterModules = qw(
    MailFilter::SuspiciousChars
    MailFilter::Virusscan
    MailFilter::BlockPartial
    MailFilter::BadFilename
    MailFilter::Anomy
    MailFilter::SpamAssassin
    MailFilter::LogMailIn
);
# If you want quarantine reports, add this filter to @FilterModules:
#   MailFilter::QuarantineNotifications
# 
# If you want to strip out HTML parts if there is a corresponding
# plain-text part, add this filter to @FilterModules:
#   MailFilter::StripUselessHTML
#
# If you want to rebuild all message to have valid MIME structure,
# add this filter to @FilterModules:
#   MailFilter::RebuildMIME

# DO NOT delete the next line, or Perl will complain.
1;

